braindecode.datautil.create_from_mne_epochs
===========================================

.. currentmodule:: braindecode.datautil

.. autofunction:: create_from_mne_epochs

.. include:: braindecode.datautil.create_from_mne_epochs.examples

.. raw:: html

    <div style='clear:both'></div>